==> meecrowave-1.2.14-source-release.zip: meecrowave-1.2.14/meecrowave-jpa/src/main/java/org/apache/meecrowave/jpa/internal/JpaInterceptorBase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.meecrowave.jpa.internal;

import javax.inject.Inject;
import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;
import java.io.Serializable;

public abstract class JpaInterceptorBase implements Serializable {
    @Inject
    private JpaExtension extension;

    @AroundInvoke
    public Object inTransaction(final InvocationContext context) throws Exception {
        final EntityManagerContext entityManagerContext = extension.getEntityManagerContext();
        final boolean owner = entityManagerContext.enter(isTransactional());
        try {
            return context.proceed();
        } catch (final Exception e) {
            entityManagerContext.failed();
            throw e;
        } finally {
            entityManagerContext.exit(owner);
        }
    }

    protected abstract boolean isTransactional();
}

==> meecrowave-2.0.0-source-release.zip: meecrowave-2.0.0/meecrowave-jpa/src/main/java/org/apache/meecrowave/jpa/internal/JpaInterceptorBase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.meecrowave.jpa.internal;

import jakarta.inject.Inject;
import jakarta.interceptor.AroundInvoke;
import jakarta.interceptor.InvocationContext;
import java.io.Serializable;

public abstract class JpaInterceptorBase implements Serializable {
    @Inject
    private JpaExtension extension;

    @AroundInvoke
    public Object inTransaction(final InvocationContext context) throws Exception {
        final EntityManagerContext entityManagerContext = extension.getEntityManagerContext();
        final boolean owner = entityManagerContext.enter(isTransactional());
        try {
            return context.proceed();
        } catch (final Exception e) {
            entityManagerContext.failed();
            throw e;
        } finally {
            entityManagerContext.exit(owner);
        }
    }

    protected abstract boolean isTransactional();
}
